What is MAICoS
==============

.. include:: ../../../README.rst
   :start-after: inclusion-readme-intro-start
   :end-before: inclusion-readme-intro-end

.. include:: ../../../README.rst
   :start-after: inclusion-marker-modules-start
   :end-before: inclusion-marker-modules-end
